@@ -1,6 +1,6 @@
 package App::optex::textconv::ooxml;
 
-our $VERSION = '0.14';
+our $VERSION = '0.1401';
 
 use v5.14;
 use warnings;
@@ -14,8 +14,7 @@ BEGIN {
 
     require App::optex::textconv::ooxml::regex;
 
-    eval { require App::optex::textconv::ooxml::xslt };
-    if ($@) {
+    if (eval { require App::optex::textconv::ooxml::xslt }) {
 	@CONVERTER = (
 	    [ qr/\.doc[xm]$/ => \&App::optex::textconv::ooxml::xslt::to_text ],
 	    [ qr/\.ppt[xm]$/ => \&App::optex::textconv::ooxml::xslt::to_text ],
